@@ -1,5 +1,7 @@
 #[cfg(feature = "debug")]
 mod debug_tests;
+#[cfg(feature = "eval")]
+mod eval_tests;
 #[cfg(any(feature = "release"))]
 mod release_tests;
 #[cfg(feature = "report")]
